package com.example.greenwatch;

import android.Manifest;
import android.content.pm.PackageManager;
import android.graphics.SurfaceTexture;
import android.os.Bundle;
import android.view.TextureView;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

public class MainActivity extends AppCompatActivity implements TextureView.SurfaceTextureListener{

    private boolean isRecording = false;
    private static final int REQUEST_PERMISSION = 200;
    private Button button;
    private TextureView textureView;
    private AlarmRecorder alarmRecorder;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        button = findViewById(R.id.button);
        textureView = findViewById(R.id.textureView);
        textureView.setSurfaceTextureListener(this);

        button.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (!isRecording) {
                    if (ContextCompat.checkSelfPermission(MainActivity.this, Manifest.permission.CAMERA)
                            != PackageManager.PERMISSION_GRANTED
                            || ContextCompat.checkSelfPermission(MainActivity.this, Manifest.permission.WRITE_EXTERNAL_STORAGE)
                            != PackageManager.PERMISSION_GRANTED
                            || ContextCompat.checkSelfPermission(MainActivity.this, Manifest.permission.RECORD_AUDIO)
                            != PackageManager.PERMISSION_GRANTED) {
                        ActivityCompat.requestPermissions(MainActivity.this,
                                new String[]{Manifest.permission.CAMERA, Manifest.permission.WRITE_EXTERNAL_STORAGE, Manifest.permission.RECORD_AUDIO},
                                REQUEST_PERMISSION);
                    } else {
                        isRecording = true;
                        alarmRecorder.startRecording();
                    }
                } else {
                    isRecording = false;
                    alarmRecorder.stopRecording();
                }
            }
        });
    }

    @Override
    public void onSurfaceTextureAvailable(SurfaceTexture surfaceTexture, int width, int height) {
        alarmRecorder = new AlarmRecorder(surfaceTexture);
    }

    @Override
    public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {
        // Die Größe der SurfaceTexture hat sich geändert
        // Hier können entsprechende Anpassungen vorgenommen werden
    }

    @Override
    public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
        // SurfaceTexture wurde zerstört
        // Hier können entsprechende Bereinigungen durchgeführt werden
        return true;
    }

    @Override
    public void onSurfaceTextureUpdated(SurfaceTexture surface) {
        // SurfaceTexture wurde aktualisiert
        // Hier können entsprechende Aktionen ausgeführt werden, wenn gewünscht
    }

    private SurfaceTexture getSurfaceTexture() {
        return textureView.getSurfaceTexture();
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == REQUEST_PERMISSION) {
            if (grantResults.length > 0 && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                // Berechtigungen wurden gewährt
                Toast.makeText(this, "Berechtigungen gewährt", Toast.LENGTH_SHORT).show();
                isRecording = true;
                alarmRecorder.startRecording();
            } else {
                // Berechtigungen wurden nicht gewährt
                Toast.makeText(this, "Berechtigungen nicht gewährt", Toast.LENGTH_SHORT).show();
            }
        }
    }
}